@@ -5,8 +5,8 @@ class IssueCreatedSnapshotStrategy(SnapshotStrategy):
     def is_snapshot_taken(self, issue):
         return True
 
-    def process(self, issue):
-        super().process(issue)
+    def process(self, issue, final_issue_state):
+        super().process(issue, final_issue_state)
 
         snapshot_issue = self.issues[issue['id']]
         if 'assignee' in issue:
@@ -16,6 +16,10 @@ class IssueCreatedSnapshotStrategy(SnapshotStrategy):
 
         if 'fixed_by' not in snapshot_issue:
             if 'state' in issue and issue['state'] == 'Fixed':
+                assignee = None
                 if 'assignee' in snapshot_issue:
-                    snapshot_issue['fixed_by'] = snapshot_issue['last_assignee']
-
+                    assignee = snapshot_issue['last_assignee']
+                elif 'assignee' in final_issue_state:
+                    assignee = final_issue_state['assignee']
+                if assignee is not None:
+                    snapshot_issue['fixed_by'] = assignee
